@@ -1,12 +1,13 @@
 use crate::PortalInternalMessage;
+use core::time::Duration;
 use ockam_core::async_trait;
 use ockam_core::compat::vec::Vec;
 use ockam_core::{route, Address, Processor, Result};
 use ockam_node::Context;
 use tokio::{io::AsyncReadExt, net::tcp::OwnedReadHalf};
-use tracing::error;
+use tracing::{error, warn};
 
-const MAX_PAYLOAD_SIZE: usize = 32 * 1024;
+const MAX_PAYLOAD_SIZE: usize = 10 * 1024;
 
 /// A TCP Portal receiving message processor
 ///
@@ -47,11 +48,18 @@ impl Processor for TcpPortalRecvProcessor {
 
         if self.buf.is_empty() {
             // Notify Sender that connection was closed
-            ctx.send(
-                route![self.sender_address.clone()],
-                PortalInternalMessage::Disconnect,
-            )
-            .await?;
+            if let Err(err) = ctx
+                .send(
+                    route![self.sender_address.clone()],
+                    PortalInternalMessage::Disconnect,
+                )
+                .await
+            {
+                warn!(
+                    "Error notifying Tcp Portal Sender about dropped connection {}",
+                    err
+                );
+            }
 
             return Ok(false);
         }
@@ -62,6 +70,7 @@ impl Processor for TcpPortalRecvProcessor {
 
             // Let Sender forward payload to the other side
             ctx.send(route![self.sender_address.clone()], msg).await?;
+            ctx.sleep(Duration::from_millis(10)).await;
         }
 
         Ok(true)
